ExtractUnsafeApis

Struct ExtractUnsafeApis 

pub struct ExtractUnsafeApis<'tcx> {
    tcx: TyCtxt<'tcx>,
}

Fields

tcx: TyCtxt<'tcx>

Implementations

Source

impl<'tcx> ExtractUnsafeApis<'tcx>

pub fn new(tcx: TyCtxt<'tcx>) -> Self

pub fn run_local(&self)

Run extract for the current (local) crate and print JSON to stderr.

pub fn run_std(&self)

Run extract for the Rust standard library and print JSON to stderr.

fn get_doc_string(&self, def_id: DefId) -> String

Collect doc comment text for a def_id by joining all #[doc = "..."] attrs.

fn get_safety_doc(&self, def_id: DefId) -> Option<String>

Extract the # Safety section from the doc comment of a def_id.

fn get_params(&self, def_id: DefId) -> Vec<ParamInfo>

Get parameter types from the function signature.

fn get_hir_param_names(&self, def_id: DefId) -> Vec<String>

Attempt to retrieve parameter names from the HIR body for a local function.

fn make_entry(&self, def_id: DefId) -> UnsafeApiEntry

Build an UnsafeApiEntry from a DefId.

fn collect_local(&self) -> Vec<UnsafeApiEntry>

Collect all public unsafe fn and AssocFn items in the local crate.

fn collect_std(&self) -> Vec<UnsafeApiEntry>

Collect all public unsafe functions from the Rust standard library.