pub struct ExtractUnsafeApis<'tcx> {
tcx: TyCtxt<'tcx>,
}Fields
tcx: TyCtxt<'tcx>Implementations
Sourceimpl<'tcx> ExtractUnsafeApis<'tcx>
impl<'tcx> ExtractUnsafeApis<'tcx>
pub fn new(tcx: TyCtxt<'tcx>) -> Self
Sourcefn get_doc_string(&self, def_id: DefId) -> String
fn get_doc_string(&self, def_id: DefId) -> String
Collect doc comment text for a def_id by joining all #[doc = "..."] attrs.
Sourcefn get_safety_doc(&self, def_id: DefId) -> Option<String>
fn get_safety_doc(&self, def_id: DefId) -> Option<String>
Extract the # Safety section from the doc comment of a def_id.
Sourcefn get_params(&self, def_id: DefId) -> Vec<ParamInfo>
fn get_params(&self, def_id: DefId) -> Vec<ParamInfo>
Get parameter types from the function signature.
Sourcefn get_hir_param_names(&self, def_id: DefId) -> Vec<String>
fn get_hir_param_names(&self, def_id: DefId) -> Vec<String>
Attempt to retrieve parameter names from the HIR body for a local function.
Sourcefn make_entry(&self, def_id: DefId) -> UnsafeApiEntry
fn make_entry(&self, def_id: DefId) -> UnsafeApiEntry
Build an UnsafeApiEntry from a DefId.
Sourcefn collect_local(&self) -> Vec<UnsafeApiEntry>
fn collect_local(&self) -> Vec<UnsafeApiEntry>
Collect all public unsafe fn and AssocFn items in the local crate.
Sourcefn collect_std(&self) -> Vec<UnsafeApiEntry>
fn collect_std(&self) -> Vec<UnsafeApiEntry>
Collect all public unsafe functions from the Rust standard library.